@@ -12,9 +12,6 @@ from spark_pipeline_framework.progress_logger.progress_logger import ProgressLog
 from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import (
     FrameworkTransformer,
 )
-from spark_pipeline_framework.utilities.FriendlySparkException import (
-    FriendlySparkException,
-)
 from spark_pipeline_framework.utilities.class_helpers import ClassHelpers
 from spark_pipeline_framework.utilities.pipeline_helper import create_steps
 
@@ -84,16 +81,16 @@ class FrameworkPipeline(Transformer):
                     f"!!!!!!!!!!!!! pipeline [{pipeline_name}] transformer [{stage_name}] threw exception !!!!!!!!!!!!!"
                 )
                 # use exception chaining to add stage name but keep original exception
-                friendly_spark_exception: FriendlySparkException = (
-                    FriendlySparkException(exception=e, stage_name=stage_name)
-                )
-                error_messages: List[str] = (
-                    friendly_spark_exception.message.split("\n")
-                    if friendly_spark_exception.message
-                    else []
-                )
-                for error_message in error_messages:
-                    logger.error(msg=error_message)
+                # friendly_spark_exception: FriendlySparkException = (
+                #     FriendlySparkException(exception=e, stage_name=stage_name)
+                # )
+                # error_messages: List[str] = (
+                #     friendly_spark_exception.message.split("\n")
+                #     if friendly_spark_exception.message
+                #     else []
+                # )
+                # for error_message in error_messages:
+                #     logger.error(msg=error_message)
 
                 if hasattr(transformer, "getSql"):
                     # noinspection Mypy
@@ -106,7 +103,12 @@ class FrameworkPipeline(Transformer):
                     event_text=f"Exception in Stage={stage_name}",
                     ex=e,
                 )
-                raise friendly_spark_exception from e
+                # if hasattr(e, "message"):
+                #     e.message = f"Exception in stage {stage_name}" + e.message
+                if len(e.args) >= 1:
+                    # e.args = (e.args[0] + f" in stage {stage_name}") + e.args[1:]
+                    e.args = (f"In Stage ({stage_name})", *e.args)
+                raise e
         self.progress_logger.log_event(
             event_name=pipeline_name, event_text=f"Finished Pipeline {pipeline_name}"
         )
